import collections
import logging
import pathlib

import yaml

from . import settings
from .data import pluginsv9

log = logging.getLogger(__name__)
CheckPlugin = collections.namedtuple("CheckPlugin", ["name", "path"])
PLUGIN_NOTES_FILE = pathlib.Path(settings.DATA_DIR) / "check_migration_plugins.yaml"


class PluginSet:
    """
    Collection of plugins available on version 9.

    Example:
        >>> ps = PluginSet()
        >>> CheckPlugin("foo", "$USER1$/foo") in ps
        True
    """

    def __init__(self):
        self._set_list(pluginsv9.PLUGIN_LIST)

    def __contains__(self, item: CheckPlugin):
        return item.name in self.plugins

    def __iter__(self):
        return iter(self.plugins)

    def _set_list(self, paths):
        # Method exists for easy override by test code.
        self.plugins = {p.name: p for p in map(pathlib.Path, paths)}


def get_plugin_notes(path=PLUGIN_NOTES_FILE):
    with path.open("rb") as fp:
        data = yaml.safe_load(fp)
    return data["plugin_notes"]
